@@ -545,10 +545,9 @@ static int handle_eventhandler( int event_type, void *data ) {
 
     temp_buffer[0]='\x0';
     snprintf( temp_buffer,GM_BUFFERSIZE-1,
-                "type=eventhandler\nstart_time=%i.0\ncore_time=%i.%i\ncommand_line=%s\n\n\n",
-                (int)core_time.tv_sec,
-                (int)core_time.tv_sec,
-                (int)core_time.tv_usec,
+                "type=eventhandler\nstart_time=%Lf\ncore_time=%Lf\ncommand_line=%s\n\n\n",
+                timeval2double(&core_time),
+                timeval2double(&core_time),
                 ds->command_line
     );
 
@@ -765,10 +764,9 @@ static int handle_notifications( int event_type, void *data ) {
 
     temp_buffer[0]='\x0';
     snprintf( temp_buffer,GM_BUFFERSIZE-1,
-                "type=notification\nstart_time=%i.0\ncore_time=%i.%i\ncontact=%s\ncommand_line=%s\nplugin_output=%s\nlong_plugin_output=%s\n\n\n",
-                (int)ds->start_time.tv_sec,
-                (int)core_time.tv_sec,
-                (int)core_time.tv_usec,
+                "type=notification\nstart_time=%Lf\ncore_time=%Lf\ncontact=%s\ncommand_line=%s\nplugin_output=%s\nlong_plugin_output=%s\n\n\n",
+                timeval2double(&ds->start_time),
+                timeval2double(&core_time),
                 ds->contact_name,
                 processed_command,
                 ds->output,
@@ -984,9 +982,6 @@ static int handle_host_check( int event_type, void *data ) {
 #ifdef USENAGIOS3
     adjust_host_check_attempt_3x(hst,TRUE);
 #endif
-#if defined(USENAEMON) || defined(USENAGIOS4)
-    adjust_host_check_attempt(hst,TRUE);
-#endif
 
     temp_buffer[0]='\x0';
 
@@ -1048,14 +1043,13 @@ static int handle_host_check( int event_type, void *data ) {
 
     gm_log( GM_LOG_TRACE, "cmd_line: %s\n", processed_command );
 
-    snprintf( temp_buffer,GM_BUFFERSIZE-1,"type=host\nresult_queue=%s\nhost_name=%s\nstart_time=%i.0\nnext_check=%i.0\ntimeout=%d\ncore_time=%i.%i\ncommand_line=%s\n\n\n",
+    snprintf( temp_buffer,GM_BUFFERSIZE-1,"type=host\nresult_queue=%s\nhost_name=%s\nstart_time=%ld.0\nnext_check=%ld.0\ntimeout=%d\ncore_time=%Lf\ncommand_line=%s\n\n\n",
               mod_gm_opt->result_queue,
               hst->name,
-              (int)hst->next_check,
-              (int)hst->next_check,
+              hst->next_check,
+              hst->next_check,
               host_check_timeout,
-              (int)core_time.tv_sec,
-              (int)core_time.tv_usec,
+              timeval2double(&core_time),
               processed_command
             );
 
@@ -1250,14 +1244,13 @@ static int handle_svc_check( int event_type, void *data ) {
 
     gm_log( GM_LOG_TRACE, "cmd_line: %s\n", processed_command );
 
-    snprintf( temp_buffer,GM_BUFFERSIZE-1,"type=service\nresult_queue=%s\nhost_name=%s\nservice_description=%s\nstart_time=%i.0\nnext_check=%i.0\ncore_time=%i.%i\ntimeout=%d\ncommand_line=%s\n\n\n",
+    snprintf( temp_buffer,GM_BUFFERSIZE-1,"type=service\nresult_queue=%s\nhost_name=%s\nservice_description=%s\nstart_time=%ld.0\nnext_check=%ld.0\ncore_time=%Lf\ntimeout=%d\ncommand_line=%s\n\n\n",
               mod_gm_opt->result_queue,
               svcdata->host_name,
               svcdata->service_description,
-              (int)svc->next_check,
-              (int)svc->next_check,
-              (int)core_time.tv_sec,
-              (int)core_time.tv_usec,
+              svc->next_check,
+              svc->next_check,
+              timeval2double(&core_time),
               service_check_timeout,
               processed_command
             );
@@ -1721,12 +1714,12 @@ int handle_export(int callback_type, void *data) {
         case NEBCALLBACK_PROCESS_DATA:                      /*  7 */
             npd    = (nebstruct_process_data *)data;
             type   = nebtype2str(npd->type);
-            snprintf( temp_buffer,GM_BUFFERSIZE-1, "{\"callback_type\":\"%s\",\"type\":\"%s\",\"flags\":%d,\"attr\":%d,\"timestamp\":%d.%d}",
+            snprintf( temp_buffer,GM_BUFFERSIZE-1, "{\"callback_type\":\"%s\",\"type\":\"%s\",\"flags\":%d,\"attr\":%d,\"timestamp\":%Lf}",
                     "NEBCALLBACK_PROCESS_DATA",
                     type,
                     npd->flags,
                     npd->attr,
-                    (int)npd->timestamp.tv_sec, (int)npd->timestamp.tv_usec
+                    timeval2double(&npd->timestamp)
                     );
             free(type);
             break;
@@ -1734,13 +1727,13 @@ int handle_export(int callback_type, void *data) {
             nted       = (nebstruct_timed_event_data *)data;
             event_type = eventtype2str(nted->event_type);
             type       = nebtype2str(nted->type);
-            snprintf( temp_buffer,GM_BUFFERSIZE-1, "{\"callback_type\":\"%s\",\"event_type\":\"%s\",\"type\":\"%s\",\"flags\":%d,\"attr\":%d,\"timestamp\":%d.%d,\"recurring\":%d,\"run_time\":%d}",
+            snprintf( temp_buffer,GM_BUFFERSIZE-1, "{\"callback_type\":\"%s\",\"event_type\":\"%s\",\"type\":\"%s\",\"flags\":%d,\"attr\":%d,\"timestamp\":%Lf,\"recurring\":%d,\"run_time\":%d}",
                     "NEBCALLBACK_TIMED_EVENT_DATA",
                     event_type,
                     type,
                     nted->flags,
                     nted->attr,
-                    (int)nted->timestamp.tv_sec, (int)nted->timestamp.tv_usec,
+                    timeval2double(&nted->timestamp),
                     nted->recurring,
                     (int)nted->run_time
                     );
@@ -1751,12 +1744,12 @@ int handle_export(int callback_type, void *data) {
             nld    = (nebstruct_log_data *)data;
             buffer = escapestring(nld->data);
             type   = nebtype2str(nld->type);
-            snprintf( temp_buffer,GM_BUFFERSIZE-1, "{\"callback_type\":\"%s\",\"type\":\"%s\",\"flags\":%d,\"attr\":%d,\"timestamp\":%d.%d,\"entry_time\":%d,\"data_type\":%d,\"data\":\"%s\"}",
+            snprintf( temp_buffer,GM_BUFFERSIZE-1, "{\"callback_type\":\"%s\",\"type\":\"%s\",\"flags\":%d,\"attr\":%d,\"timestamp\":%Lf,\"entry_time\":%d,\"data_type\":%d,\"data\":\"%s\"}",
                     "NEBCALLBACK_LOG_DATA",
                     type,
                     nld->flags,
                     nld->attr,
-                    (int)nld->timestamp.tv_sec, (int)nld->timestamp.tv_usec,
+                    timeval2double(&nld->timestamp),
                     (int)nld->entry_time,
                     nld->data_type,
                     buffer);
