@@ -2,6 +2,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <math.h>
 
 #include <t/tap.h>
 #include <common.h>
@@ -30,7 +31,7 @@ mod_gm_opt_t * renew_opts() {
 }
 
 int main(void) {
-    plan(69);
+    plan(73);
 
     /* lowercase */
     char test[100];
@@ -150,9 +151,15 @@ int main(void) {
 
     /* string2timeval */
     struct timeval t;
-    string2timeval("100.50", &t);
+    string2timeval("100.000050", &t);
     ok(t.tv_sec  == 100, "string2timeval 1");
     ok(t.tv_usec == 50, "string2timeval 2");
+    ok(fabs(timeval2double(&t) - 100.00005) < 0.00001, "timeval2double 1");
+
+    string2timeval("100.5", &t);
+    ok(t.tv_sec  == 100, "string2timeval 1b");
+    ok(t.tv_usec == 500000, "string2timeval 2b");
+    ok(fabs(timeval2double(&t) - 100.5) < 0.00001, "timeval2double 2");
 
     string2timeval("100", &t);
     ok(t.tv_sec  == 100, "string2timeval 3");
@@ -179,7 +186,7 @@ int main(void) {
     mod_gm_opt = renew_opts();
     strcpy(test, "server=:4730");
     parse_args_line(mod_gm_opt, test, 0);
-    like(mod_gm_opt->server_list[0]->host, "localhost", "server=:4730");
+    like(mod_gm_opt->server_list[0]->host, "0.0.0.0", "server=:4730");
     ok(mod_gm_opt->server_list[0]->port == 4730, "server=:4730");
     ok(mod_gm_opt->server_num == 1, "server_number = %d", mod_gm_opt->server_num);
 
@@ -199,9 +206,9 @@ int main(void) {
     parse_args_line(mod_gm_opt, test, 0);
     like(mod_gm_opt->server_list[0]->host, "localhost", "duplicate server");
     ok(mod_gm_opt->server_list[0]->port == 4730, "duplicate server");
-    like(mod_gm_opt->server_list[1]->host, "host", "duplicate server");
-    ok(mod_gm_opt->server_list[1]->port == 4730, "duplicate server");
-    ok(mod_gm_opt->server_num == 2, "server_number = %d", mod_gm_opt->server_num);
+    like(mod_gm_opt->server_list[2]->host, "host", "duplicate server");
+    ok(mod_gm_opt->server_list[2]->port == 4730, "duplicate server");
+    ok(mod_gm_opt->server_num == 3, "server_number = %d", mod_gm_opt->server_num);
 
     /* escape newlines */
     char * escaped = gm_escape_newlines(" test\n", GM_DISABLED);
