@@ -78,13 +78,15 @@ void worker_client(int worker_mode, int indx, int shid) {
         clean_worker_exit(0);
         _exit( EXIT_FAILURE );
     }
+    current_client = &client;
 
     /* create duplicate client */
     if( mod_gm_opt->dupserver_num ) {
-        if ( create_client_dup( mod_gm_opt->dupserver_list, &client_dup ) != GM_OK ) {
+        if ( create_client( mod_gm_opt->dupserver_list, &client_dup ) != GM_OK ) {
             gm_log( GM_LOG_ERROR, "cannot start client for duplicate server\n" );
             _exit( EXIT_FAILURE );
         }
+        current_client_dup = &client_dup;
     }
 
 #ifdef EMBEDDEDPERL
@@ -137,8 +139,11 @@ void worker_loop() {
             /* create new connections */
             set_worker( &worker );
             create_client( mod_gm_opt->server_list, &client );
-            if( mod_gm_opt->dupserver_num )
-                create_client_dup( mod_gm_opt->dupserver_list, &client_dup );
+            current_client = &client;
+            if( mod_gm_opt->dupserver_num ) {
+                create_client( mod_gm_opt->dupserver_list, &client_dup );
+                current_client_dup = &client_dup;
+            }
         }
     }
 
